@@ -15,13 +15,13 @@
 #' @param show.all.nodes A Logical variable, default: true
 #' @param threshold A vector of numeric min/max values, default: c(0,Inf) plotting . Edge weights below the min value will not be displayed; edge weights above the max value will be shown at the max value.
 #' @param thin.lines.in.front A logical, default: true
-#' @param opacity A vector of numeric min/max values for opacity, default: (0.3,1)
-#' @param saturation A vector of numeric min/max values for saturation, default: (0.25, 1)
-#' @param thickness A vector of numeric min/max values for thickness, default: (0, 1)
+#' @param thickness A vector of numeric min/max values for thickness, default:  c(min(abs(network)), max(abs(network)))
+#' @param opacity A vector of numeric min/max values for opacity, default: thickness
+#' @param saturation A vector of numeric min/max values for saturation, default: thickness
+#' @param scale.range A vector of numeric min/max to scale from, default: c(0.1,1) or if min(network) is 0, c(0,1)
 #' @param node.size A lower and upper bound used for scaling the size of the nodes, default c(0, 20)
 #' @param labels A character vector of node labels, default: code names
 #' @param label.offset A character vector of representing the positional offset relative to the respective node. Defaults to "middle right" for all nodes. If a single values is provided, it is used for all positions, else the length of the
-#' provided label.offset must be equal to the length of the labels vector
 #' @param label.font.size An integer which determines the font size for graph labels, default: enaplot$font.size
 #' @param label.font.color A character which determines the color of label font, default: enaplot$font.color
 #' @param label.font.family A character which determines font type, choices: Arial, Courier New, Times New Roman, default: enaplot$font.family
@@ -96,10 +96,14 @@ ena.plot.network = function(
   show.all.nodes = T,
   threshold = c(0),
   thin.lines.in.front = T,
-  opacity = c(0.3,1),
-  saturation = c(0.25,1),
-  thickness = c(0.1,1),
+
+  thickness = c(min(abs(network)), max(abs(network))),
+  opacity = thickness,
+  saturation = thickness,
+  scale.range = c(ifelse(min(network)==0, 0, 0.1), 1),
+
   node.size = c(3,10),
+
   labels = rownames(node.positions),
   label.offset = "middle right",
   label.font.size = enaplot$get("font.size"),
@@ -153,26 +157,27 @@ ena.plot.network = function(
       network.scaled[to.threshold] = network.scaled[to.threshold] * multiplier.mask[to.threshold]
     }
   }
-  network.thickness = network.scaled;
-  network.saturation = network.scaled;
-  network.opacity = network.scaled;
+  network.thickness = abs(network.scaled);
+  network.saturation = abs(network.scaled);
+  network.opacity = abs(network.scaled);
 
   network.to.keep = (network != 0) * 1
   if(!is.null(args$scale.weights) && args$scale.weights == T) {
     network.scaled = network * (1 / max(abs(network)));
 
-    network.thickness = scales::rescale(abs(network.scaled), thickness);
+    network.thickness = scales::rescale(x = abs(network.scaled), to = scale.range, from = thickness);
   }
   network.scaled = network.scaled * network.to.keep
   network.thickness = network.thickness * network.to.keep
 
-  network.saturation = scales::rescale(abs(network.scaled), saturation);
-  network.opacity = scales::rescale(abs(network.scaled), opacity);
+  network.saturation = scales::rescale(x = abs(network.scaled), to = scale.range, from = saturation);
+  network.opacity = scales::rescale(x = abs(network.scaled), to = scale.range, from = opacity);
 
   pos.inds = as.numeric(which(network.scaled >=0));
   neg.inds = as.numeric(which(network.scaled < 0));
 
   colors.hsv = rgb2hsv(col2rgb(colors))
+
   if(ncol(colors.hsv) == 1) {
     colors.hsv[[4]] = colors.hsv[1] + 0.5;
     if(colors.hsv[4] > 1) {
@@ -183,13 +188,12 @@ ena.plot.network = function(
     colors.hsv[[6]] = colors.hsv[3];
     dim(colors.hsv) = c(3,2);
   }
-
   mat = adjacency.key;
   for (i in 1:length(network)) {
     v0 <- node.positions[node.rows==mat[1,i], ];
     v1 <- node.positions[node.rows==mat[2,i], ];
-    nodes[node.rows==mat[1,i],]$weight = nodes[node.rows==mat[1,i],]$weight + network.thickness[i];
-    nodes[node.rows==mat[2,i],]$weight = nodes[node.rows==mat[2,i],]$weight + network.thickness[i];
+    nodes[node.rows==mat[1,i],]$weight = nodes[node.rows==mat[1,i],]$weight + abs(network.thickness[i]);
+    nodes[node.rows==mat[2,i],]$weight = nodes[node.rows==mat[2,i],]$weight + abs(network.thickness[i]);
 
     color = NULL
     if(i %in% pos.inds) {
@@ -206,7 +210,7 @@ ena.plot.network = function(
       line = list(
         name = "test",
         color= hsv(color[1],color[2],color[3]),
-        width= network.thickness[i] * enaplot$get("multiplier")
+        width= abs(network.thickness[i]) * enaplot$get("multiplier")
       ),
       x0 = v0[1],
       y0 = v0[2],
